@@ -18,6 +18,7 @@
 // Copyright (C) 2016 Tor Lillqvist <tml@collabora.com>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -34,12 +35,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "0.79.0"
-#endif
-
-/* Use fixedpoint. */
-#ifndef USE_FIXEDPOINT
-/* #undef USE_FIXEDPOINT */
+#define POPPLER_VERSION "0.80.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -115,6 +111,11 @@
 #define USE_CMS 1
 #endif
 
+/* Use header-only classes from Boost in the Splash backend */
+#ifndef USE_BOOST_HEADERS
+#define USE_BOOST_HEADERS 1
+#endif
+
 //------------------------------------------------------------------------
 // version
 //------------------------------------------------------------------------
